<?php # $Id: lang_bg.inc.php 2089 2008-01-13 19:52:42Z jwalker $

/**
 *  @version $Revision: 2089 $
 *  @author Ivan Cenov jwalker@hotmail.bg
 */

    @define('PLUGIN_COMMENTS_BLAHBLAH', '     ');
    @define('PLUGIN_COMMENTS_WORDWRAP', '   ');
    @define('PLUGIN_COMMENTS_WORDWRAP_BLAHBLAH', '         ( : 30)');
    @define('PLUGIN_COMMENTS_MAXCHARS', '     ');
    @define('PLUGIN_COMMENTS_MAXCHARS_BLAHBLAH', '         ( : 120)');
    @define('PLUGIN_COMMENTS_MAXENTRIES', '    ');
    @define('PLUGIN_COMMENTS_MAXENTRIES_BLAHBLAH', '  -    ( : 15)');
    @define('PLUGIN_COMMENTS_ABOUT', '%s %s');
    @define('PLUGIN_COMMENTS_ANONYMOUS', '');
